/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.basic.info.modular.unitInfo.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.auth.core.util.StpClientUtil;
import com.unis.auth.modular.login.entity.UserCollectLogin;
import com.unis.basic.info.modular.grainPriceCollectCategory.entity.GrainPriceCollectCategory;
import com.unis.basic.info.modular.grainPriceCollectCitySum.entity.GrainPriceCollectCitySum;
import com.unis.common.pojo.CommonResult;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.basic.info.modular.unitInfo.entity.UnitInfo;
import com.unis.basic.info.modular.unitInfo.mapper.UnitInfoMapper;
import com.unis.basic.info.modular.unitInfo.param.UnitInfoAddParam;
import com.unis.basic.info.modular.unitInfo.param.UnitInfoEditParam;
import com.unis.basic.info.modular.unitInfo.param.UnitInfoIdParam;
import com.unis.basic.info.modular.unitInfo.param.UnitInfoPageParam;
import com.unis.basic.info.modular.unitInfo.service.UnitInfoService;

import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * 单位信息表Service接口实现类
 *
 * @author hujinachun
 * @date 2024/04/16 09:08
 **/
@Slf4j
@Service
public class UnitInfoServiceImpl extends ServiceImpl<UnitInfoMapper, UnitInfo> implements UnitInfoService {


    @Autowired
    private UnitInfoMapper unitInfoMapper;

    @Override
    public Page<UnitInfo> page(UnitInfoPageParam pageParam) {
        QueryWrapper<UnitInfo> queryWrapper = new QueryWrapper<>();
        if (StringUtils.isNotBlank(pageParam.getDwmc())) {
            queryWrapper.like("dwmc", pageParam.getDwmc());
        }
        if (StringUtils.isNotBlank(pageParam.getFddbr())) {
            queryWrapper.like("fddbr", pageParam.getFddbr());
        }
        if (ObjectUtil.isAllNotEmpty(pageParam.getSortField(), pageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(pageParam.getSortOrder());
            queryWrapper.orderBy(true, pageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(pageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(UnitInfo::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    /**
     * @author: hujianchun
     * @Description:
     * @param:
     * @return: 添加企业信息
     */
    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(UnitInfoAddParam unitInfoAddParam) {
       /* UnitInfo unitInfo = BeanUtil.toBean(unitInfoAddParam, UnitInfo.class);
        this.save(unitInfo);*/
        List<UnitInfo> unitInfos = unitInfoMapper.selectList(Wrappers.lambdaQuery(UnitInfo.class).eq(UnitInfo::getDwdm, unitInfoAddParam.getDwdm()));
        if (!CollectionUtils.isEmpty(unitInfos)) {
            throw new CommonException("单位统一社会信用代码重复，请重新输入");
        }
        List<UnitInfo> unitInfoList = unitInfoMapper.selectList(Wrappers.lambdaQuery(UnitInfo.class).eq(UnitInfo::getDwmc, unitInfoAddParam.getDwmc()));
        if (!CollectionUtils.isEmpty(unitInfoList)) {
            throw new CommonException("单位名称重复，请重新输入");
        }
        if (unitInfoAddParam.getDwdm().length() != 18 && unitInfoAddParam.getSjdwdm().length() != 18) {
            throw new CommonException("统一社会信用代码格式错误");
        }
        if (unitInfoAddParam.getFrsfzh().length() != 18) {
            throw new CommonException("身份证号格式错误");
        }
        UnitInfo unitInfo = new UnitInfo();
        BeanUtils.copyProperties(unitInfoAddParam, unitInfo);
        unitInfo.setZhgxsj(new Date());
        unitInfo.setCreateTime(new Date());
        unitInfo.setCzbz("i");
        try {
            unitInfoMapper.insert(unitInfo);
        } catch (Exception e) {
            log.error("单位管理信息新增操作数据库失败:[{}]" + e.getMessage());
            throw new CommonException("单位管理信息新增操作数据库失败");
        }


    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(UnitInfoEditParam unitInfoEditParam) {
       /* UnitInfo unitInfo = this.queryEntity(unitInfoEditParam.getId());
        BeanUtil.copyProperties(unitInfoEditParam, unitInfo);
        this.updateById(unitInfo);*/
        List<UnitInfo> unitInfos = unitInfoMapper.selectList(Wrappers.lambdaQuery(UnitInfo.class)
                .eq(UnitInfo::getDwdm, unitInfoEditParam.getDwdm()));
        if (!CollectionUtils.isEmpty(unitInfos)) {
            throw new CommonException("单位统一社会信用代码重复，请重新输入");
        }
        List<UnitInfo> unitInfoList = unitInfoMapper.selectList(Wrappers.lambdaQuery(UnitInfo.class)
                .eq(UnitInfo::getDwmc, unitInfoEditParam.getDwmc()));
        if (!CollectionUtils.isEmpty(unitInfoList)) {
            throw new CommonException("单位名称重复，请重新输入");
        }

        UnitInfo unitInfo = new UnitInfo();
        BeanUtils.copyProperties(unitInfoEditParam, unitInfo);
        unitInfo.setCzbz("u");
        unitInfo.setId(unitInfoEditParam.getId());
        unitInfo.setUpdateTime(new Date());
        try {
            unitInfoMapper.updateById(unitInfo);
        } catch (Exception e) {
            log.error("单位管理信息修改操作数据库失败异常信息[{}],id:[{}]", e.getMessage(), unitInfoEditParam.getId());
            throw new CommonException("单位管理信息新增操作数据库失败");
        }

    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<UnitInfoIdParam> unitInfoIdParamList) {

        // 执行删除
        this.removeByIds(CollStreamUtil.toList(unitInfoIdParamList, UnitInfoIdParam::getId));

    }

    @Override
    public UnitInfo detail(UnitInfoIdParam unitInfoIdParam) {
        return this.queryEntity(unitInfoIdParam.getId());
    }

    @Override
    public UnitInfo queryEntity(String id) {
        UnitInfo unitInfo = this.getById(id);
        if (ObjectUtil.isEmpty(unitInfo)) {
            throw new CommonException("单位信息表不存在，id值为：{}", id);
        }
        return unitInfo;
    }
}
